# tomato: au-tomation without pain!

[![Documentation](https://badgen.net/badge/docs/dgbowl.github.io/grey?icon=firefox)](https://dgbowl.github.io/tomato)
[![PyPi version](https://badgen.net/pypi/v/dgpost/?icon=pypi)](https://pypi.org/project/tomato)
![Github link](https://badgen.net/github/tag/dgbowl/tomato/?icon=github)
![Github status](https://badgen.net/github/checks/dgbowl/tomato/?icon=github)

`tomato` is the instrument automation package developed at the [ConCat lab at TU Berlin](https://tu.berlin/en/concat). Currently supported hardware is:

- [`tomato-example-counter`](https://github.com/dgbowl/tomato-example-counter): an example device for testing purposes.
- [`tomato-psutil`](https://github.com/dgbowl/tomato-psutil): an interface to the `psutil` library for CPU and memory usage statistics
- [`tomato-bronkhorst`](https://github.com/dgbowl/tomato-bronkhorst): an interface to the `bronkhorst-propar` library for control of Bronkhorst MFCs and PCs
- [`tomato-jumo`](https://github.com/dgbowl/tomato-jumo): a driver for control of Jumo Quantrol heater controllers using `minimalmodbus`

See the [Documentation](https://dgbowl.github.io/tomato) for more detailed info.

## Contributors:
- [Peter Kraus](http://github.com/PeterKraus)
- [Alexandre Gbocho](https://github.com/AlexN7-Shepard)
- [Loris Ercole](http://github.com/lorisercole)
- [Graham Kimbell](http://github.com/g-kimbell)

## Acknowledgements

This project has received funding from:
- the European Union’s Horizon 2020 research and innovation programme under grant agreement No 957189.
- the Emmy Noether Programme of the Deutsche Forschungsgemeinschaft (DFG) under project No 490703766.
- the Priority Programme (SPP) 2419 HyCAM of the Deutsche Forschungsemeinschaft (DFG) under project No 523873650.

The project is part of BATTERY 2030+, the large-scale European research initiative for inventing the sustainable batteries of the future.
